@@ -9,7 +9,7 @@ logging.basicConfig(stream=sys.stdout, level=os.environ.get('LOGLEVEL', 'INFO').
 
 logger = logging.getLogger(__name__)
 
-site_base = "https://dev.aeroplatform.co.uk"
+site_base = "https://site.aeroplatform.co.uk"
 name_lower = "aero"
 name_upper = "Aero"
 
@@ -34,24 +34,30 @@ def account():
     pass
 
 @account.command(help="Login to an account")
-def login():
+@click.option("--email", default=None,
+    help="Email address")
+@click.option("--password", default=None,
+    help="Password")
+def login(password, email):
     echo(f'{magenta(name_upper + " Platform")} running under Python {sys.version}.')
     echo("A Data Platform designed to put developers first.")
     echo("")
 
-    email = click.prompt("Email > ")
-    password = click.prompt("Password > ", hide_input=True)
+    if not email and not password:
+        email = click.prompt("Email > ")
+        password = click.prompt("Password > ", hide_input=True)
 
     try:
-        account = _login(email, password)
+        account = Account(email, password)
+        _login(account)
     except Exception as e:
         echo("An error occured when attempting to log in, please try again")
         logger.debug(e)
         return
 
-    # TODO: Check if already provisioned. AWS creds need refreshing though.
     try:
         _provision(account)
+
     except Exception as e:
         echo("An error occured when attempting to provision, please try again")
         logger.debug(e)
@@ -67,10 +73,10 @@ def create():
     return
 
 
-def _login(email, password):
+def _login(account):
 
     try:
-        acc = Account.login(email, password)
+        account.login()
     except Exception as e:
 
         if str(e) == "403":
@@ -85,23 +91,24 @@ def _login(email, password):
     
     echo(f'{cyan("Login Successful")}')
 
-    return acc
-
 def _provision(account):
 
     status = ComputeStatus.NO_VALUE
     i = 0
+    is_first_provision = False
 
     while status != ComputeStatus.CREATED:
-        status = account.provision()
+        status = account.provision(is_first_provision)
         logger.debug(f"Current Status is {status}, iteration {i}")
 
         if status == ComputeStatus.INIT:
             echo(f"Initialised Compute Environment Creation")
+            is_first_provision = True
 
         if status == ComputeStatus.CREATING:
             echo(f"Creating Compute Environment...")   
-    
+            is_first_provision = True
+
         if status == ComputeStatus.CREATED:
             echo(f"Compute Environment Created")
             echo(f"You are now ready to run Flows with Aero. For more, read here: {site_base}")
